# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.invoice_customer import InvoiceCustomer  # noqa: F401,E501
from cardpay.model.invoice_data import InvoiceData  # noqa: F401,E501
from cardpay.model.invoice_merchant_order import InvoiceMerchantOrder  # noqa: F401,E501
from cardpay.model.request import Request  # noqa: F401,E501
from cardpay.model.return_urls import ReturnUrls  # noqa: F401,E501


class InvoiceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "request": "Request",
        "customer": "InvoiceCustomer",
        "invoice_data": "InvoiceData",
        "merchant_order": "InvoiceMerchantOrder",
        "return_urls": "ReturnUrls",
    }

    attribute_map = {
        "request": "request",
        "customer": "customer",
        "invoice_data": "invoice_data",
        "merchant_order": "merchant_order",
        "return_urls": "return_urls",
    }

    def __init__(
        self,
        request=None,
        customer=None,
        invoice_data=None,
        merchant_order=None,
        return_urls=None,
    ):  # noqa: E501
        """InvoiceRequest - a model defined in Swagger"""  # noqa: E501

        self._request = None
        self._customer = None
        self._invoice_data = None
        self._merchant_order = None
        self._return_urls = None
        self.discriminator = None

        self.request = request
        if customer is not None:
            self.customer = customer
        self.invoice_data = invoice_data
        self.merchant_order = merchant_order
        if return_urls is not None:
            self.return_urls = return_urls

    @property
    def request(self):
        """Gets the request of this InvoiceRequest.  # noqa: E501

        Request  # noqa: E501

        :return: The request of this InvoiceRequest.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this InvoiceRequest.

        Request  # noqa: E501

        :param request: The request of this InvoiceRequest.  # noqa: E501
        :type: Request
        """
        if request is None:
            raise ValueError(
                "Invalid value for `request`, must not be `None`"
            )  # noqa: E501

        self._request = request

    @property
    def customer(self):
        """Gets the customer of this InvoiceRequest.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this InvoiceRequest.  # noqa: E501
        :rtype: InvoiceCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this InvoiceRequest.

        Customer data  # noqa: E501

        :param customer: The customer of this InvoiceRequest.  # noqa: E501
        :type: InvoiceCustomer
        """

        self._customer = customer

    @property
    def invoice_data(self):
        """Gets the invoice_data of this InvoiceRequest.  # noqa: E501

        Invoice data  # noqa: E501

        :return: The invoice_data of this InvoiceRequest.  # noqa: E501
        :rtype: InvoiceData
        """
        return self._invoice_data

    @invoice_data.setter
    def invoice_data(self, invoice_data):
        """Sets the invoice_data of this InvoiceRequest.

        Invoice data  # noqa: E501

        :param invoice_data: The invoice_data of this InvoiceRequest.  # noqa: E501
        :type: InvoiceData
        """
        if invoice_data is None:
            raise ValueError(
                "Invalid value for `invoice_data`, must not be `None`"
            )  # noqa: E501

        self._invoice_data = invoice_data

    @property
    def merchant_order(self):
        """Gets the merchant_order of this InvoiceRequest.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this InvoiceRequest.  # noqa: E501
        :rtype: InvoiceMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this InvoiceRequest.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this InvoiceRequest.  # noqa: E501
        :type: InvoiceMerchantOrder
        """
        if merchant_order is None:
            raise ValueError(
                "Invalid value for `merchant_order`, must not be `None`"
            )  # noqa: E501

        self._merchant_order = merchant_order

    @property
    def return_urls(self):
        """Gets the return_urls of this InvoiceRequest.  # noqa: E501

        Return URLs are the URLs where customer returns by pressing 'Back to the shop' or 'Cancel' button in Payment Page mode  # noqa: E501

        :return: The return_urls of this InvoiceRequest.  # noqa: E501
        :rtype: ReturnUrls
        """
        return self._return_urls

    @return_urls.setter
    def return_urls(self, return_urls):
        """Sets the return_urls of this InvoiceRequest.

        Return URLs are the URLs where customer returns by pressing 'Back to the shop' or 'Cancel' button in Payment Page mode  # noqa: E501

        :param return_urls: The return_urls of this InvoiceRequest.  # noqa: E501
        :type: ReturnUrls
        """

        self._return_urls = return_urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InvoiceRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CardInfoResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "bin": "str",
        "card_brand": "str",
        "card_issuer": "str",
        "card_type": "str",
        "country": "str",
    }

    attribute_map = {
        "bin": "bin",
        "card_brand": "card_brand",
        "card_issuer": "card_issuer",
        "card_type": "card_type",
        "country": "country",
    }

    def __init__(
        self, bin=None, card_brand=None, card_issuer=None, card_type=None, country=None
    ):  # noqa: E501
        """CardInfoResponse - a model defined in Swagger"""  # noqa: E501

        self._bin = None
        self._card_brand = None
        self._card_issuer = None
        self._card_type = None
        self._country = None
        self.discriminator = None

        if bin is not None:
            self.bin = bin
        if card_brand is not None:
            self.card_brand = card_brand
        if card_issuer is not None:
            self.card_issuer = card_issuer
        if card_type is not None:
            self.card_type = card_type
        if country is not None:
            self.country = country

    @property
    def bin(self):
        """Gets the bin of this CardInfoResponse.  # noqa: E501

        Card BIN  # noqa: E501

        :return: The bin of this CardInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._bin

    @bin.setter
    def bin(self, bin):
        """Sets the bin of this CardInfoResponse.

        Card BIN  # noqa: E501

        :param bin: The bin of this CardInfoResponse.  # noqa: E501
        :type: str
        """

        self._bin = bin

    @property
    def card_brand(self):
        """Gets the card_brand of this CardInfoResponse.  # noqa: E501

        Card brand  # noqa: E501

        :return: The card_brand of this CardInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_brand

    @card_brand.setter
    def card_brand(self, card_brand):
        """Sets the card_brand of this CardInfoResponse.

        Card brand  # noqa: E501

        :param card_brand: The card_brand of this CardInfoResponse.  # noqa: E501
        :type: str
        """

        self._card_brand = card_brand

    @property
    def card_issuer(self):
        """Gets the card_issuer of this CardInfoResponse.  # noqa: E501

        Card issuer name  # noqa: E501

        :return: The card_issuer of this CardInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_issuer

    @card_issuer.setter
    def card_issuer(self, card_issuer):
        """Sets the card_issuer of this CardInfoResponse.

        Card issuer name  # noqa: E501

        :param card_issuer: The card_issuer of this CardInfoResponse.  # noqa: E501
        :type: str
        """

        self._card_issuer = card_issuer

    @property
    def card_type(self):
        """Gets the card_type of this CardInfoResponse.  # noqa: E501

        Card type  # noqa: E501

        :return: The card_type of this CardInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._card_type

    @card_type.setter
    def card_type(self, card_type):
        """Sets the card_type of this CardInfoResponse.

        Card type  # noqa: E501

        :param card_type: The card_type of this CardInfoResponse.  # noqa: E501
        :type: str
        """

        self._card_type = card_type

    @property
    def country(self):
        """Gets the country of this CardInfoResponse.  # noqa: E501

        Country code in [ISO 3166-1](https://en.wikipedia.org/wiki/ISO_3166-1) alpha-2 code format  # noqa: E501

        :return: The country of this CardInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this CardInfoResponse.

        Country code in [ISO 3166-1](https://en.wikipedia.org/wiki/ISO_3166-1) alpha-2 code format  # noqa: E501

        :param country: The country of this CardInfoResponse.  # noqa: E501
        :type: str
        """

        self._country = country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(CardInfoResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CardInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PayoutResponseCustomer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "email": "str",
        "id": "str",
        "ip_country": "str",
        "phone": "str",
        "user_agent": "str",
    }

    attribute_map = {
        "email": "email",
        "id": "id",
        "ip_country": "ip_country",
        "phone": "phone",
        "user_agent": "user_agent",
    }

    def __init__(
        self, email=None, id=None, ip_country=None, phone=None, user_agent=None
    ):  # noqa: E501
        """PayoutResponseCustomer - a model defined in Swagger"""  # noqa: E501

        self._email = None
        self._id = None
        self._ip_country = None
        self._phone = None
        self._user_agent = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if id is not None:
            self.id = id
        if ip_country is not None:
            self.ip_country = ip_country
        if phone is not None:
            self.phone = phone
        if user_agent is not None:
            self.user_agent = user_agent

    @property
    def email(self):
        """Gets the email of this PayoutResponseCustomer.  # noqa: E501

        Customer's e-mail address, here can be value returned from payment method - in case then in Merchant request `customer.email` wasn't presented  # noqa: E501

        :return: The email of this PayoutResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PayoutResponseCustomer.

        Customer's e-mail address, here can be value returned from payment method - in case then in Merchant request `customer.email` wasn't presented  # noqa: E501

        :param email: The email of this PayoutResponseCustomer.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def id(self):
        """Gets the id of this PayoutResponseCustomer.  # noqa: E501

        Customer's ID in Merchant's system  # noqa: E501

        :return: The id of this PayoutResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PayoutResponseCustomer.

        Customer's ID in Merchant's system  # noqa: E501

        :param id: The id of this PayoutResponseCustomer.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ip_country(self):
        """Gets the ip_country of this PayoutResponseCustomer.  # noqa: E501

        Customer country by IP  # noqa: E501

        :return: The ip_country of this PayoutResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._ip_country

    @ip_country.setter
    def ip_country(self, ip_country):
        """Sets the ip_country of this PayoutResponseCustomer.

        Customer country by IP  # noqa: E501

        :param ip_country: The ip_country of this PayoutResponseCustomer.  # noqa: E501
        :type: str
        """

        self._ip_country = ip_country

    @property
    def phone(self):
        """Gets the phone of this PayoutResponseCustomer.  # noqa: E501

        Customer's phone  # noqa: E501

        :return: The phone of this PayoutResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this PayoutResponseCustomer.

        Customer's phone  # noqa: E501

        :param phone: The phone of this PayoutResponseCustomer.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def user_agent(self):
        """Gets the user_agent of this PayoutResponseCustomer.  # noqa: E501

        User agent  # noqa: E501

        :return: The user_agent of this PayoutResponseCustomer.  # noqa: E501
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """Sets the user_agent of this PayoutResponseCustomer.

        User agent  # noqa: E501

        :param user_agent: The user_agent of this PayoutResponseCustomer.  # noqa: E501
        :type: str
        """

        self._user_agent = user_agent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PayoutResponseCustomer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutResponseCustomer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InvoiceGetDataResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "currency": "str",
        "expire_at": "datetime",
        "id": "str",
        "status": "str",
    }

    attribute_map = {
        "amount": "amount",
        "currency": "currency",
        "expire_at": "expire_at",
        "id": "id",
        "status": "status",
    }

    def __init__(
        self, amount=None, currency=None, expire_at=None, id=None, status=None
    ):  # noqa: E501
        """InvoiceGetDataResponse - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._currency = None
        self._expire_at = None
        self._id = None
        self._status = None
        self.discriminator = None

        self.amount = amount
        self.currency = currency
        if expire_at is not None:
            self.expire_at = expire_at
        self.id = id
        if status is not None:
            self.status = status

    @property
    def amount(self):
        """Gets the amount of this InvoiceGetDataResponse.  # noqa: E501

        The total invoice amount in selected currency with dot as a decimal separator  # noqa: E501

        :return: The amount of this InvoiceGetDataResponse.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoiceGetDataResponse.

        The total invoice amount in selected currency with dot as a decimal separator  # noqa: E501

        :param amount: The amount of this InvoiceGetDataResponse.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this InvoiceGetDataResponse.  # noqa: E501

        ISO 4217 currency code  # noqa: E501

        :return: The currency of this InvoiceGetDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoiceGetDataResponse.

        ISO 4217 currency code  # noqa: E501

        :param currency: The currency of this InvoiceGetDataResponse.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def expire_at(self):
        """Gets the expire_at of this InvoiceGetDataResponse.  # noqa: E501

        Date of invoice expiring. Invoice cannot be used after this date.  # noqa: E501

        :return: The expire_at of this InvoiceGetDataResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._expire_at

    @expire_at.setter
    def expire_at(self, expire_at):
        """Sets the expire_at of this InvoiceGetDataResponse.

        Date of invoice expiring. Invoice cannot be used after this date.  # noqa: E501

        :param expire_at: The expire_at of this InvoiceGetDataResponse.  # noqa: E501
        :type: datetime
        """

        self._expire_at = expire_at

    @property
    def id(self):
        """Gets the id of this InvoiceGetDataResponse.  # noqa: E501

        Identifier of created invoice.  # noqa: E501

        :return: The id of this InvoiceGetDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvoiceGetDataResponse.

        Identifier of created invoice.  # noqa: E501

        :param id: The id of this InvoiceGetDataResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def status(self):
        """Gets the status of this InvoiceGetDataResponse.  # noqa: E501

        Status of invoice.  # noqa: E501

        :return: The status of this InvoiceGetDataResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InvoiceGetDataResponse.

        Status of invoice.  # noqa: E501

        :param status: The status of this InvoiceGetDataResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InvoiceGetDataResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceGetDataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InvoiceData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "currency": "str",
        "expire_at": "datetime",
        "installment_type": "str",
        "installments": "list[int]",
    }

    attribute_map = {
        "amount": "amount",
        "currency": "currency",
        "expire_at": "expire_at",
        "installment_type": "installment_type",
        "installments": "installments",
    }

    def __init__(
        self,
        amount=None,
        currency=None,
        expire_at=None,
        installment_type=None,
        installments=None,
    ):  # noqa: E501
        """InvoiceData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._currency = None
        self._expire_at = None
        self._installment_type = None
        self._installments = None
        self.discriminator = None

        self.amount = amount
        self.currency = currency
        if expire_at is not None:
            self.expire_at = expire_at
        if installment_type is not None:
            self.installment_type = installment_type
        if installments is not None:
            self.installments = installments

    @property
    def amount(self):
        """Gets the amount of this InvoiceData.  # noqa: E501

        The total invoice amount in selected currency with dot as a decimal separator, must be less than 10 billion  # noqa: E501

        :return: The amount of this InvoiceData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoiceData.

        The total invoice amount in selected currency with dot as a decimal separator, must be less than 10 billion  # noqa: E501

        :param amount: The amount of this InvoiceData.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this InvoiceData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this InvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoiceData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this InvoiceData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def expire_at(self):
        """Gets the expire_at of this InvoiceData.  # noqa: E501

        Date and time of invoice expiring. Invoice cannot be used after this date and time.  # noqa: E501

        :return: The expire_at of this InvoiceData.  # noqa: E501
        :rtype: datetime
        """
        return self._expire_at

    @expire_at.setter
    def expire_at(self, expire_at):
        """Sets the expire_at of this InvoiceData.

        Date and time of invoice expiring. Invoice cannot be used after this date and time.  # noqa: E501

        :param expire_at: The expire_at of this InvoiceData.  # noqa: E501
        :type: datetime
        """

        self._expire_at = expire_at

    @property
    def installment_type(self):
        """Gets the installment_type of this InvoiceData.  # noqa: E501

        Installment type  # noqa: E501

        :return: The installment_type of this InvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._installment_type

    @installment_type.setter
    def installment_type(self, installment_type):
        """Sets the installment_type of this InvoiceData.

        Installment type  # noqa: E501

        :param installment_type: The installment_type of this InvoiceData.  # noqa: E501
        :type: str
        """

        self._installment_type = installment_type

    @property
    def installments(self):
        """Gets the installments of this InvoiceData.  # noqa: E501

        Number of installments. It depends on country.  # noqa: E501

        :return: The installments of this InvoiceData.  # noqa: E501
        :rtype: list[int]
        """
        return self._installments

    @installments.setter
    def installments(self, installments):
        """Sets the installments of this InvoiceData.

        Number of installments. It depends on country.  # noqa: E501

        :param installments: The installments of this InvoiceData.  # noqa: E501
        :type: list[int]
        """

        self._installments = installments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InvoiceData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.supported_payment_method import (
    SupportedPaymentMethod,
)  # noqa: F401,E501


class PaymentMethodsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "brands": "list[str]",
        "category": "str",
        "name": "str",
        "supported_payment_methods": "list[SupportedPaymentMethod]",
    }

    attribute_map = {
        "brands": "brands",
        "category": "category",
        "name": "name",
        "supported_payment_methods": "supported_payment_methods",
    }

    def __init__(
        self, brands=None, category=None, name=None, supported_payment_methods=None
    ):  # noqa: E501
        """PaymentMethodsResponse - a model defined in Swagger"""  # noqa: E501

        self._brands = None
        self._category = None
        self._name = None
        self._supported_payment_methods = None
        self.discriminator = None

        if brands is not None:
            self.brands = brands
        if category is not None:
            self.category = category
        if name is not None:
            self.name = name
        if supported_payment_methods is not None:
            self.supported_payment_methods = supported_payment_methods

    @property
    def brands(self):
        """Gets the brands of this PaymentMethodsResponse.  # noqa: E501

        Available Card Brands, is presented only for 'BANKCARD' payment method  # noqa: E501

        :return: The brands of this PaymentMethodsResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._brands

    @brands.setter
    def brands(self, brands):
        """Sets the brands of this PaymentMethodsResponse.

        Available Card Brands, is presented only for 'BANKCARD' payment method  # noqa: E501

        :param brands: The brands of this PaymentMethodsResponse.  # noqa: E501
        :type: list[str]
        """

        self._brands = brands

    @property
    def category(self):
        """Gets the category of this PaymentMethodsResponse.  # noqa: E501

        Payment method category  # noqa: E501

        :return: The category of this PaymentMethodsResponse.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this PaymentMethodsResponse.

        Payment method category  # noqa: E501

        :param category: The category of this PaymentMethodsResponse.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def name(self):
        """Gets the name of this PaymentMethodsResponse.  # noqa: E501

        Payment method name  # noqa: E501

        :return: The name of this PaymentMethodsResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentMethodsResponse.

        Payment method name  # noqa: E501

        :param name: The name of this PaymentMethodsResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def supported_payment_methods(self):
        """Gets the supported_payment_methods of this PaymentMethodsResponse.  # noqa: E501

        Supported payment methods  # noqa: E501

        :return: The supported_payment_methods of this PaymentMethodsResponse.  # noqa: E501
        :rtype: list[SupportedPaymentMethod]
        """
        return self._supported_payment_methods

    @supported_payment_methods.setter
    def supported_payment_methods(self, supported_payment_methods):
        """Sets the supported_payment_methods of this PaymentMethodsResponse.

        Supported payment methods  # noqa: E501

        :param supported_payment_methods: The supported_payment_methods of this PaymentMethodsResponse.  # noqa: E501
        :type: list[SupportedPaymentMethod]
        """

        self._supported_payment_methods = supported_payment_methods

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentMethodsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentMethodsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InvoiceItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"count": "int", "name": "str", "price": "float"}

    attribute_map = {"count": "count", "name": "name", "price": "price"}

    def __init__(self, count=None, name=None, price=None):  # noqa: E501
        """InvoiceItem - a model defined in Swagger"""  # noqa: E501

        self._count = None
        self._name = None
        self._price = None
        self.discriminator = None

        self.count = count
        self.name = name
        self.price = price

    @property
    def count(self):
        """Gets the count of this InvoiceItem.  # noqa: E501

        The count of product / service, provided to the customer. Any positive number  # noqa: E501

        :return: The count of this InvoiceItem.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this InvoiceItem.

        The count of product / service, provided to the customer. Any positive number  # noqa: E501

        :param count: The count of this InvoiceItem.  # noqa: E501
        :type: int
        """
        if count is None:
            raise ValueError(
                "Invalid value for `count`, must not be `None`"
            )  # noqa: E501
        if count is not None and count < 1:  # noqa: E501
            raise ValueError(
                "Invalid value for `count`, must be a value greater than or equal to `1`"
            )  # noqa: E501

        self._count = count

    @property
    def name(self):
        """Gets the name of this InvoiceItem.  # noqa: E501

        The name of product / service, provided to the customer  # noqa: E501

        :return: The name of this InvoiceItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InvoiceItem.

        The name of product / service, provided to the customer  # noqa: E501

        :param name: The name of this InvoiceItem.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501
        if name is not None and len(name) > 50:
            raise ValueError(
                "Invalid value for `name`, length must be less than or equal to `50`"
            )  # noqa: E501
        if name is not None and len(name) < 1:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._name = name

    @property
    def price(self):
        """Gets the price of this InvoiceItem.  # noqa: E501

        Price of product / service with dot as a decimal separator, must be less than a 1000000 (one million, NOT inclusive)  For currencies with 0 digits after digital separator (like VND, IDR and others) - limit is 200000000 (200 million, NOT inclusive)  # noqa: E501

        :return: The price of this InvoiceItem.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this InvoiceItem.

        Price of product / service with dot as a decimal separator, must be less than a 1000000 (one million, NOT inclusive)  For currencies with 0 digits after digital separator (like VND, IDR and others) - limit is 200000000 (200 million, NOT inclusive)  # noqa: E501

        :param price: The price of this InvoiceItem.  # noqa: E501
        :type: float
        """
        if price is None:
            raise ValueError(
                "Invalid value for `price`, must not be `None`"
            )  # noqa: E501

        self._price = price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InvoiceItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.invoice_item import InvoiceItem  # noqa: F401,E501


class InvoiceMerchantOrder(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"id": "str", "items": "list[InvoiceItem]"}

    attribute_map = {"id": "id", "items": "items"}

    def __init__(self, id=None, items=None):  # noqa: E501
        """InvoiceMerchantOrder - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._items = None
        self.discriminator = None

        self.id = id
        self.items = items

    @property
    def id(self):
        """Gets the id of this InvoiceMerchantOrder.  # noqa: E501

        Order ID used by the merchant’s shopping cart  # noqa: E501

        :return: The id of this InvoiceMerchantOrder.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvoiceMerchantOrder.

        Order ID used by the merchant’s shopping cart  # noqa: E501

        :param id: The id of this InvoiceMerchantOrder.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if id is not None and len(id) > 50:
            raise ValueError(
                "Invalid value for `id`, length must be less than or equal to `50`"
            )  # noqa: E501
        if id is not None and len(id) < 1:
            raise ValueError(
                "Invalid value for `id`, length must be greater than or equal to `1`"
            )  # noqa: E501

        self._id = id

    @property
    def items(self):
        """Gets the items of this InvoiceMerchantOrder.  # noqa: E501

        Array of items (in the shopping cart)  # noqa: E501

        :return: The items of this InvoiceMerchantOrder.  # noqa: E501
        :rtype: list[InvoiceItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this InvoiceMerchantOrder.

        Array of items (in the shopping cart)  # noqa: E501

        :param items: The items of this InvoiceMerchantOrder.  # noqa: E501
        :type: list[InvoiceItem]
        """
        if items is None:
            raise ValueError(
                "Invalid value for `items`, must not be `None`"
            )  # noqa: E501

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InvoiceMerchantOrder, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceMerchantOrder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.payment_gateway_response_payment_data import (
    PaymentGatewayResponsePaymentData,
)  # noqa: F401,E501


class PaymentGatewayCreationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "payment_data": "PaymentGatewayResponsePaymentData",
        "redirect_url": "str",
    }

    attribute_map = {"payment_data": "payment_data", "redirect_url": "redirect_url"}

    def __init__(self, payment_data=None, redirect_url=None):  # noqa: E501
        """PaymentGatewayCreationResponse - a model defined in Swagger"""  # noqa: E501

        self._payment_data = None
        self._redirect_url = None
        self.discriminator = None

        if payment_data is not None:
            self.payment_data = payment_data
        if redirect_url is not None:
            self.redirect_url = redirect_url

    @property
    def payment_data(self):
        """Gets the payment_data of this PaymentGatewayCreationResponse.  # noqa: E501

        Payment data  # noqa: E501

        :return: The payment_data of this PaymentGatewayCreationResponse.  # noqa: E501
        :rtype: PaymentGatewayResponsePaymentData
        """
        return self._payment_data

    @payment_data.setter
    def payment_data(self, payment_data):
        """Sets the payment_data of this PaymentGatewayCreationResponse.

        Payment data  # noqa: E501

        :param payment_data: The payment_data of this PaymentGatewayCreationResponse.  # noqa: E501
        :type: PaymentGatewayResponsePaymentData
        """

        self._payment_data = payment_data

    @property
    def redirect_url(self):
        """Gets the redirect_url of this PaymentGatewayCreationResponse.  # noqa: E501

        URL Customer should be redirected to  # noqa: E501

        :return: The redirect_url of this PaymentGatewayCreationResponse.  # noqa: E501
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """Sets the redirect_url of this PaymentGatewayCreationResponse.

        URL Customer should be redirected to  # noqa: E501

        :param redirect_url: The redirect_url of this PaymentGatewayCreationResponse.  # noqa: E501
        :type: str
        """

        self._redirect_url = redirect_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(PaymentGatewayCreationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentGatewayCreationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.recurring_response_filing import (
    RecurringResponseFiling,
)  # noqa: F401,E501


class ScheduledByMerchantData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "amount": "float",
        "contract_number": "str",
        "currency": "str",
        "dynamic_descriptor": "str",
        "filing": "RecurringResponseFiling",
        "generate_token": "bool",
        "initiator": "str",
        "network_trans_id": "str",
        "note": "str",
        "scheduled_type": "str",
        "three_ds_challenge_indicator": "str",
        "trans_type": "str",
    }

    attribute_map = {
        "amount": "amount",
        "contract_number": "contract_number",
        "currency": "currency",
        "dynamic_descriptor": "dynamic_descriptor",
        "filing": "filing",
        "generate_token": "generate_token",
        "initiator": "initiator",
        "network_trans_id": "network_trans_id",
        "note": "note",
        "scheduled_type": "scheduled_type",
        "three_ds_challenge_indicator": "three_ds_challenge_indicator",
        "trans_type": "trans_type",
    }

    def __init__(
        self,
        amount=None,
        contract_number=None,
        currency=None,
        dynamic_descriptor=None,
        filing=None,
        generate_token=None,
        initiator=None,
        network_trans_id=None,
        note=None,
        scheduled_type=None,
        three_ds_challenge_indicator=None,
        trans_type=None,
    ):  # noqa: E501
        """ScheduledByMerchantData - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._contract_number = None
        self._currency = None
        self._dynamic_descriptor = None
        self._filing = None
        self._generate_token = None
        self._initiator = None
        self._network_trans_id = None
        self._note = None
        self._scheduled_type = None
        self._three_ds_challenge_indicator = None
        self._trans_type = None
        self.discriminator = None

        self.amount = amount
        if contract_number is not None:
            self.contract_number = contract_number
        self.currency = currency
        if dynamic_descriptor is not None:
            self.dynamic_descriptor = dynamic_descriptor
        if filing is not None:
            self.filing = filing
        if generate_token is not None:
            self.generate_token = generate_token
        self.initiator = initiator
        if network_trans_id is not None:
            self.network_trans_id = network_trans_id
        if note is not None:
            self.note = note
        self.scheduled_type = scheduled_type
        if three_ds_challenge_indicator is not None:
            self.three_ds_challenge_indicator = three_ds_challenge_indicator
        if trans_type is not None:
            self.trans_type = trans_type

    @property
    def amount(self):
        """Gets the amount of this ScheduledByMerchantData.  # noqa: E501

        The amount of scheduled payment to be charged  # noqa: E501

        :return: The amount of this ScheduledByMerchantData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this ScheduledByMerchantData.

        The amount of scheduled payment to be charged  # noqa: E501

        :param amount: The amount of this ScheduledByMerchantData.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError(
                "Invalid value for `amount`, must not be `None`"
            )  # noqa: E501

        self._amount = amount

    @property
    def contract_number(self):
        """Gets the contract_number of this ScheduledByMerchantData.  # noqa: E501

        Contract number between customer and merchant. Required for Mexican merchants for scheduled payments.  # noqa: E501

        :return: The contract_number of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._contract_number

    @contract_number.setter
    def contract_number(self, contract_number):
        """Sets the contract_number of this ScheduledByMerchantData.

        Contract number between customer and merchant. Required for Mexican merchants for scheduled payments.  # noqa: E501

        :param contract_number: The contract_number of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """

        self._contract_number = contract_number

    @property
    def currency(self):
        """Gets the currency of this ScheduledByMerchantData.  # noqa: E501

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :return: The currency of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ScheduledByMerchantData.

        [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code  # noqa: E501

        :param currency: The currency of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """
        if currency is None:
            raise ValueError(
                "Invalid value for `currency`, must not be `None`"
            )  # noqa: E501

        self._currency = currency

    @property
    def dynamic_descriptor(self):
        """Gets the dynamic_descriptor of this ScheduledByMerchantData.  # noqa: E501

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :return: The dynamic_descriptor of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_descriptor

    @dynamic_descriptor.setter
    def dynamic_descriptor(self, dynamic_descriptor):
        """Sets the dynamic_descriptor of this ScheduledByMerchantData.

        Short description of the service or product, must be enabled by CardPay manager to be used.  # noqa: E501

        :param dynamic_descriptor: The dynamic_descriptor of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """
        if dynamic_descriptor is not None and len(dynamic_descriptor) > 25:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be less than or equal to `25`"
            )  # noqa: E501
        if dynamic_descriptor is not None and len(dynamic_descriptor) < 0:
            raise ValueError(
                "Invalid value for `dynamic_descriptor`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._dynamic_descriptor = dynamic_descriptor

    @property
    def filing(self):
        """Gets the filing of this ScheduledByMerchantData.  # noqa: E501

        Card filing data  # noqa: E501

        :return: The filing of this ScheduledByMerchantData.  # noqa: E501
        :rtype: RecurringResponseFiling
        """
        return self._filing

    @filing.setter
    def filing(self, filing):
        """Sets the filing of this ScheduledByMerchantData.

        Card filing data  # noqa: E501

        :param filing: The filing of this ScheduledByMerchantData.  # noqa: E501
        :type: RecurringResponseFiling
        """

        self._filing = filing

    @property
    def generate_token(self):
        """Gets the generate_token of this ScheduledByMerchantData.  # noqa: E501

        This attribute can be received only in first recurring request. In all requests with recurring_id card.token can't be generated. If set to 'true', Card token will be generated and returned in GET response. Will be generated only for successful transactions (not for declined).  # noqa: E501

        :return: The generate_token of this ScheduledByMerchantData.  # noqa: E501
        :rtype: bool
        """
        return self._generate_token

    @generate_token.setter
    def generate_token(self, generate_token):
        """Sets the generate_token of this ScheduledByMerchantData.

        This attribute can be received only in first recurring request. In all requests with recurring_id card.token can't be generated. If set to 'true', Card token will be generated and returned in GET response. Will be generated only for successful transactions (not for declined).  # noqa: E501

        :param generate_token: The generate_token of this ScheduledByMerchantData.  # noqa: E501
        :type: bool
        """

        self._generate_token = generate_token

    @property
    def initiator(self):
        """Gets the initiator of this ScheduledByMerchantData.  # noqa: E501

        Use `cit` for initiator attribute for cardholder initiated transactions (first scheduled payment by merchant transactions) Use `mit` for initiator attribute for merchant initiated transactions (continue scheduled payment by merchant transactions)  # noqa: E501

        :return: The initiator of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._initiator

    @initiator.setter
    def initiator(self, initiator):
        """Sets the initiator of this ScheduledByMerchantData.

        Use `cit` for initiator attribute for cardholder initiated transactions (first scheduled payment by merchant transactions) Use `mit` for initiator attribute for merchant initiated transactions (continue scheduled payment by merchant transactions)  # noqa: E501

        :param initiator: The initiator of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """
        if initiator is None:
            raise ValueError(
                "Invalid value for `initiator`, must not be `None`"
            )  # noqa: E501
        if initiator is not None and not re.search(r"mit|cit", initiator):  # noqa: E501
            raise ValueError(
                r"Invalid value for `initiator`, must be a follow pattern or equal to `/mit|cit/`"
            )  # noqa: E501

        self._initiator = initiator

    @property
    def network_trans_id(self):
        """Gets the network_trans_id of this ScheduledByMerchantData.  # noqa: E501

        Network Reference Number of original transaction  # noqa: E501

        :return: The network_trans_id of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._network_trans_id

    @network_trans_id.setter
    def network_trans_id(self, network_trans_id):
        """Sets the network_trans_id of this ScheduledByMerchantData.

        Network Reference Number of original transaction  # noqa: E501

        :param network_trans_id: The network_trans_id of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """

        self._network_trans_id = network_trans_id

    @property
    def note(self):
        """Gets the note of this ScheduledByMerchantData.  # noqa: E501

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :return: The note of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this ScheduledByMerchantData.

        Note about the recurring that will not be displayed to customer.  # noqa: E501

        :param note: The note of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError(
                "Invalid value for `note`, length must be less than or equal to `100`"
            )  # noqa: E501
        if note is not None and len(note) < 0:
            raise ValueError(
                "Invalid value for `note`, length must be greater than or equal to `0`"
            )  # noqa: E501

        self._note = note

    @property
    def scheduled_type(self):
        """Gets the scheduled_type of this ScheduledByMerchantData.  # noqa: E501

        Scheduled payment type attribute. For scheduled payments by merchant value should be `SM` - scheduled by merchant  # noqa: E501

        :return: The scheduled_type of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._scheduled_type

    @scheduled_type.setter
    def scheduled_type(self, scheduled_type):
        """Sets the scheduled_type of this ScheduledByMerchantData.

        Scheduled payment type attribute. For scheduled payments by merchant value should be `SM` - scheduled by merchant  # noqa: E501

        :param scheduled_type: The scheduled_type of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """
        if scheduled_type is None:
            raise ValueError(
                "Invalid value for `scheduled_type`, must not be `None`"
            )  # noqa: E501
        if scheduled_type is not None and not re.search(
            r"SM", scheduled_type
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `scheduled_type`, must be a follow pattern or equal to `/SM/`"
            )  # noqa: E501

        self._scheduled_type = scheduled_type

    @property
    def three_ds_challenge_indicator(self):
        """Gets the three_ds_challenge_indicator of this ScheduledByMerchantData.  # noqa: E501


        :return: The three_ds_challenge_indicator of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._three_ds_challenge_indicator

    @three_ds_challenge_indicator.setter
    def three_ds_challenge_indicator(self, three_ds_challenge_indicator):
        """Sets the three_ds_challenge_indicator of this ScheduledByMerchantData.


        :param three_ds_challenge_indicator: The three_ds_challenge_indicator of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """
        if three_ds_challenge_indicator is not None and not re.search(
            r"01|04", three_ds_challenge_indicator
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `three_ds_challenge_indicator`, must be a follow pattern or equal to `/01|04/`"
            )  # noqa: E501

        self._three_ds_challenge_indicator = three_ds_challenge_indicator

    class TransType(object):
        _01 = "01"
        _03 = "03"
        _10 = "10"
        _11 = "11"
        _28 = "28"

    @property
    def trans_type(self):
        """Gets the trans_type of this ScheduledByMerchantData.  # noqa: E501


        :return: The trans_type of this ScheduledByMerchantData.  # noqa: E501
        :rtype: str
        """
        return self._trans_type

    @trans_type.setter
    def trans_type(self, trans_type):
        """Sets the trans_type of this ScheduledByMerchantData.


        :param trans_type: The trans_type of this ScheduledByMerchantData.  # noqa: E501
        :type: str
        """
        allowed_values = ["01", "03", "10", "11", "28"]  # noqa: E501
        if trans_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trans_type` ({0}), must be one of {1}".format(  # noqa: E501
                    trans_type, allowed_values
                )
            )

        self._trans_type = trans_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ScheduledByMerchantData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduledByMerchantData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cardpay.model.invoice_customer import InvoiceCustomer  # noqa: F401,E501
from cardpay.model.invoice_get_data_response import (
    InvoiceGetDataResponse,
)  # noqa: F401,E501
from cardpay.model.invoice_merchant_order import InvoiceMerchantOrder  # noqa: F401,E501


class InvoiceGetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "customer": "InvoiceCustomer",
        "invoice_data": "InvoiceGetDataResponse",
        "invoice_url": "str",
        "merchant_order": "InvoiceMerchantOrder",
    }

    attribute_map = {
        "customer": "customer",
        "invoice_data": "invoice_data",
        "invoice_url": "invoice_url",
        "merchant_order": "merchant_order",
    }

    def __init__(
        self, customer=None, invoice_data=None, invoice_url=None, merchant_order=None
    ):  # noqa: E501
        """InvoiceGetResponse - a model defined in Swagger"""  # noqa: E501

        self._customer = None
        self._invoice_data = None
        self._invoice_url = None
        self._merchant_order = None
        self.discriminator = None

        self.customer = customer
        self.invoice_data = invoice_data
        if invoice_url is not None:
            self.invoice_url = invoice_url
        self.merchant_order = merchant_order

    @property
    def customer(self):
        """Gets the customer of this InvoiceGetResponse.  # noqa: E501

        Customer data  # noqa: E501

        :return: The customer of this InvoiceGetResponse.  # noqa: E501
        :rtype: InvoiceCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this InvoiceGetResponse.

        Customer data  # noqa: E501

        :param customer: The customer of this InvoiceGetResponse.  # noqa: E501
        :type: InvoiceCustomer
        """
        if customer is None:
            raise ValueError(
                "Invalid value for `customer`, must not be `None`"
            )  # noqa: E501

        self._customer = customer

    @property
    def invoice_data(self):
        """Gets the invoice_data of this InvoiceGetResponse.  # noqa: E501

        Invoice data  # noqa: E501

        :return: The invoice_data of this InvoiceGetResponse.  # noqa: E501
        :rtype: InvoiceGetDataResponse
        """
        return self._invoice_data

    @invoice_data.setter
    def invoice_data(self, invoice_data):
        """Sets the invoice_data of this InvoiceGetResponse.

        Invoice data  # noqa: E501

        :param invoice_data: The invoice_data of this InvoiceGetResponse.  # noqa: E501
        :type: InvoiceGetDataResponse
        """
        if invoice_data is None:
            raise ValueError(
                "Invalid value for `invoice_data`, must not be `None`"
            )  # noqa: E501

        self._invoice_data = invoice_data

    @property
    def invoice_url(self):
        """Gets the invoice_url of this InvoiceGetResponse.  # noqa: E501

        Invoice URL  # noqa: E501

        :return: The invoice_url of this InvoiceGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._invoice_url

    @invoice_url.setter
    def invoice_url(self, invoice_url):
        """Sets the invoice_url of this InvoiceGetResponse.

        Invoice URL  # noqa: E501

        :param invoice_url: The invoice_url of this InvoiceGetResponse.  # noqa: E501
        :type: str
        """

        self._invoice_url = invoice_url

    @property
    def merchant_order(self):
        """Gets the merchant_order of this InvoiceGetResponse.  # noqa: E501

        Merchant order data  # noqa: E501

        :return: The merchant_order of this InvoiceGetResponse.  # noqa: E501
        :rtype: InvoiceMerchantOrder
        """
        return self._merchant_order

    @merchant_order.setter
    def merchant_order(self, merchant_order):
        """Sets the merchant_order of this InvoiceGetResponse.

        Merchant order data  # noqa: E501

        :param merchant_order: The merchant_order of this InvoiceGetResponse.  # noqa: E501
        :type: InvoiceMerchantOrder
        """
        if merchant_order is None:
            raise ValueError(
                "Invalid value for `merchant_order`, must not be `None`"
            )  # noqa: E501

        self._merchant_order = merchant_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(InvoiceGetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceGetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
